summaryrefslogtreecommitdiff
path: root/buffer.h
diff options
context:
space:
mode:
authorChristian Pointner <equinox@anytun.org>2007-06-20 22:38:51 +0000
committerChristian Pointner <equinox@anytun.org>2007-06-20 22:38:51 +0000
commit55decc856579b7beffb75d71940b27fe6768e83e (patch)
tree0da7ac25a05cd71b4d47b486a4ab25f95bb56c92 /buffer.h
parentadded syslog class (diff)
first test of whole system
Diffstat (limited to 'buffer.h')
-rw-r--r--buffer.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/buffer.h b/buffer.h
index be46910..ecd31f6 100644
--- a/buffer.h
+++ b/buffer.h
@@ -31,7 +31,10 @@
#ifndef _BUFFER_H_
#define _BUFFER_H_
+#include "datatypes.h"
+
class TunDevice;
+class UDPPacketSource;
class Buffer
{
@@ -51,8 +54,9 @@ public:
u_int8_t operator[](u_int32_t index) const;
protected:
- operator u_int8_t*(); // just for write/read tun
+ operator u_int8_t*(); // just for write/read tun and packetSource
friend class TunDevice;
+ friend class UDPPacketSource;
u_int8_t *buf_;
u_int32_t length_;